Class: DevStructure::Puppet::Class
- Defined in:
- lib/devstructure/puppet.rb
Overview
Class is also a useful resource type but needs a little more help because of the stricter rules governing class names in the Puppet grammar. The most common problem is a dot in a package name (like ruby1.8, which we replace with -- in the generated code).
Instance Attribute Summary
Attributes inherited from Resource
Instance Method Summary collapse
Methods inherited from Resource
[], defaults, #initialize, #pretty_print, #to_s
Constructor Details
This class inherits a constructor from DevStructure::Puppet::Resource
Instance Method Details
#inspect ⇒ Object
323 324 325 |
# File 'lib/devstructure/puppet.rb', line 323 def inspect "#{@type.capitalize}[\"#{@name.gsub(".", "--")}\"]" end |