Class: DevStructure::Puppet::Package
- Defined in:
- lib/devstructure/puppet.rb
Overview
As mentioned earlier, we use the class name to determine the resource type. The most common types are Package, Exec, and File.
Instance Attribute Summary
Attributes inherited from Resource
Method Summary
Methods inherited from Resource
[], defaults, #initialize, #inspect, #pretty_print, #to_s
Constructor Details
This class inherits a constructor from DevStructure::Puppet::Resource